@@ -15,11 +15,13 @@
 #include "mk4_data.h"
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
 #include <math.h>
 #include <string.h>
+#include <limits.h>
 #include "param_struct.h"
 #include "filter.h"
 #include "statistics.h"
@@ -28,6 +30,10 @@
 #include "type_comp.h"
 #include "cpgplot.h"
 
+#ifdef P_tmpdir
+# define P_tmpdir "/tmp"
+#endif /* P_tmpdir */
+
 #define pi 3.141592654
                                         /* Set up some convenient macros */
                                         /* for inserting justified text using */         
@@ -95,19 +101,23 @@ struct type_221 **t221)
     extern int test_mode;
     extern int msglev;
     extern char control_filename[];
+    extern char *pexec;
+    extern char version_no[], progname[];
+    extern char *sprint_char_arr(), *sprint_date();
+    extern double c_phase(), c_mag();
     struct date tmp_date;
-    struct stat file_status;
-    double c_phase(), c_mag();
+    struct stat file_status, xeq_stat;
     int i, line, j, maxj, k, dist, plotchans, pcref, pcrem, ref, started, end_at;
     int start_plot, limit_plot;
-    char *rootname, *temp, *ps_file, *sprint_char_arr(), *sprint_date();
+    char *rootname, *temp;
     char buf[256], buf2[256], psbuf[256], device[256], output_filename[256];
     char pol[3],input_filename[256];
     float tempfl,mb_width;
     double phase, ampl, drate, mbd, sbd;
     time_t tm;
-    struct tm *utc_now, *gmtime();
-    float xr[2*MAXMAX], yr[2*MAXMAX], xmin, xmax, ymax, sec1, sec2, plotwidth;
+    struct tm *utc_now, *gmtime(), *utc_pgm;
+    float xr[2*MAXMAX], yr[2*MAXMAX], zr[2*MAXMAX];
+    float xmin, xmax, ymin, ymax, sec1, sec2, plotwidth;
     float xpos, xposref,xposrem, ypos, spacing, offset, labelpos, lwid, yplace;
     double max_dr_win, max_sb_win, max_mb_win;
     double plotstart, plotdur, plotend, totdur, tickinc, majinc, ticksize;
@@ -116,12 +126,17 @@ struct type_221 **t221)
     int totpts, wrap, len, first, nb, fd, size, filesize;
     int nlsb, nusb, izero, numsb, srate;
     int pcaref, pcarem;
-    FILE *fp, *gs;
+    FILE *fp, *gs, *popfil;
     char *pplot, *showpage, *end, trailer[1024];
+    char absexec[256], which_command[256];
+    char buffer[32];
     static char *pcstr[5]={"","NORMAL","AP BY AP","MANUAL", "MULTITONE"};
+    static char ps_file[1024];
                                         /* Create a temporary file to hold */
                                         /* the postscript output */
-    ps_file = tmpnam (NULL);
+    // ps_file = tmpnam (NULL);
+    strcpy(ps_file, P_tmpdir "/fourfit_XXXXXX");
+    close(mkstemp(ps_file));
     msg ("Temporary postscript filename = '%s'", 0, ps_file);
                                         /* Build the proper device string for */
                                         /* vertically oriented color postscript */
@@ -129,7 +144,7 @@ struct type_221 **t221)
                                         /* Open the pgplot device */
     if (cpgopen (device) <= 0)
         {
-        msg ("Postscript plot open failed", 2);
+        msg ("Postscript plot open failed (%s)", 2, ps_file);
         return (-1);
         }
                                         /* Redefine pgplot green to be a bit darker */
@@ -330,12 +345,16 @@ struct type_221 **t221)
         {
         xr[i] = xstart + (xend - xstart) * i / ncp;
         yr[i] = c_mag (plot.cp_spectrum[i+izero]);
+        zr[i] = c_phase (plot.cp_spectrum[i+izero]) * 57.3;
         if (yr[i] > ymax) ymax = yr[i];
         }
+    ymin = (param.passband[0] == 0.0 && param.passband[1] == 1.0E6)
+         ? 0 : ymax * 9e-3;                 /* about 3 pixels at 300px/in */
+    for (i=0; i<ncp; i++) if (yr[i] < ymin) zr[i] = 0;
     ymax *= 1.2;
     if (ymax == 0.0)
         {
-        msg ("overriding ymax of 0 in crosspower spectrum plot; data suspect", 2);
+        msg ("overriding ymax of 0 in Xpower Spectrum plot; data suspect", 2);
         ymax = 1.0;
         }
     cpgsvp (0.43, 0.80, 0.63, 0.74);
@@ -362,10 +381,9 @@ struct type_221 **t221)
     cpgsch (0.5);
     cpgbox ("", 0.0, 0.0, "CMST", 90.0, 3.0);
     cpgsch (0.7);
-    for (i=0; i<ncp; i++) yr[i] = c_phase (plot.cp_spectrum[i+izero]) * 57.3;
     cpgsci (2);
     cpgslw (5.0);
-    cpgpt (ncp, xr, yr, -1);
+    cpgpt (ncp, xr, zr, -1);
     cpgslw (1.0);
     cpgmtxt ("R", 2.0, 0.5, 0.5, "phase (deg)");
                                         /* Now set up channel/time plots */
@@ -880,10 +898,14 @@ struct type_221 **t221)
     pscat ("/SR {dup stringwidth neg exch neg exch rmoveto show} def\n");
     pscat ("/M {moveto} def\n");
     pscat ("/Helvetica-Bold findfont 180 scalefont setfont\n");
+
     if (param.corr_type == DIFX)
-        psleft (0.0, 0.98, "Mk4/DiFX Fringe Plot")
+        sprintf (buffer, "Mk4/DiFX %s %s rev %hd", 
+                 progname, version_no, fringe.t200->software_rev[0]);
     else
-        psleft (0.0, 0.98, "Mk4/Hdw. Fringe Plot")
+        sprintf (buffer, "Mk4/hdw. %s %s rev %hd", 
+                 progname, version_no, fringe.t200->software_rev[0]);
+    psleft (0.0, 0.98, buffer)
                                         /* Identification information */
     if ((rootname = strrchr (root->filename, '/')) == NULL)
         rootname = root->filename;
@@ -915,18 +937,17 @@ struct type_221 **t221)
     ypos -= spacing;
     sprintf (buf, "%.1f", fringe.t208->snr);
     psright (1.0, ypos, buf); ypos -= spacing;
-    sprintf (buf, "%.1e", fringe.t208->prob_false);
-    psright (1.0, ypos, buf); ypos -= spacing;
     sprintf (buf, "%.3f", fringe.t206->intg_time);
     psright (1.0, ypos, buf); ypos -= spacing;
     sprintf (buf, "%.3f", fringe.t208->amplitude * 10000.);
     psright (1.0, ypos, buf); ypos -= spacing;
     sprintf (buf, "%.1f", fringe.t208->resphase);
     psright (1.0, ypos, buf); ypos -= spacing;
+    sprintf (buf, "%.1e", fringe.t208->prob_false);
+    psright (1.0, ypos, buf); ypos -= spacing;
     ypos -= spacing;
     sprintf (buf, "%.6f", fringe.t208->resid_sbd);
     psright (1.0, ypos, buf); ypos -= spacing;
-    ypos -= spacing;
     sprintf (buf, "%.6f", fringe.t208->resid_mbd);
     psright (1.0, ypos, buf); ypos -= spacing;
     ypos -= spacing;
@@ -971,6 +992,7 @@ struct type_221 **t221)
                                 fringe.t200->corr_date.minute,
                                 (int)fringe.t200->corr_date.second);
     psright (1.0, ypos, buf); ypos -= 2.0 * spacing;
+                                    // fourfit execution timestamp
     year = fringe.t200->fourfit_date.year;
     if (year < 150) year += 1900;
     sprintf (buf, "%d:%03d:%02d%02d%02d", year,
@@ -978,6 +1000,18 @@ struct type_221 **t221)
                                 fringe.t200->fourfit_date.hour,
                                 fringe.t200->fourfit_date.minute,
                                 (int)fringe.t200->fourfit_date.second);
+    psright (1.0, ypos, buf); ypos -= spacing;
+                                    // fourfit executable timestamp
+    sprintf (which_command, "which %s", pexec);
+                                    // use which command to get absolute path
+    popfil = popen (which_command, "r");
+    fscanf (popfil, "%s", absexec);
+    pclose (popfil);
+                                    // use stat to get file creation timestamp
+    stat (absexec, &xeq_stat);
+    utc_pgm = gmtime (&(xeq_stat.st_mtime));
+    sprintf (buf, "%d:%03d:%02d%02d%02d", utc_pgm->tm_year+1900, utc_pgm->tm_yday+1,
+                     utc_pgm->tm_hour, utc_pgm->tm_min, utc_pgm->tm_sec);
     psright (1.0, ypos, buf); ypos -= 2.0 * spacing;
     sprintf (buf, "%02dh%02dm%7.4fs", fringe.t201->coord.ra_hrs,
                             fringe.t201->coord.ra_mins,
@@ -992,12 +1026,13 @@ struct type_221 **t221)
     ypos = 0.945;
     psleft (0.87, ypos, "Fringe quality"); ypos -= 2.0 * spacing;
     psleft (0.87, ypos, "SNR"); ypos -= spacing;
-    psleft (0.87, ypos, "PFD"); ypos -= spacing;
     psleft (0.87, ypos, "Intg.time"); ypos -= spacing;
     psleft (0.87, ypos, "Amp"); ypos -= spacing;
     psleft (0.87, ypos, "Phase"); ypos -= spacing;
-    psleft (0.87, ypos, "Sbdelay (us)"); ypos -= 2.0 * spacing;
-    psleft (0.87, ypos, "Mbdelay (us)"); ypos -= 2.0 * spacing;
+    psleft (0.87, ypos, "PFD"); ypos -= spacing;
+    psleft (0.87, ypos, "Delays (us)"); ypos -= spacing;
+    psleft (0.87, ypos, "SBD"); ypos -= spacing;
+    psleft (0.87, ypos, "MBD"); ypos -= spacing;
     psleft (0.87, ypos, "Fr. rate (Hz)"); ypos -= 2.0 * spacing;
     psleft (0.87, ypos, "Ref freq (MHz)"); ypos -= 2.0 * spacing;
     psleft (0.87, ypos, "AP (sec)"); ypos -= 1.5 * spacing;
@@ -1010,10 +1045,10 @@ struct type_221 **t221)
     
     psleft (0.87, ypos, "Correlation date"); 
     ypos -= 2.0 * spacing;
-    psleft (0.87, ypos, "Fourfit date:"); ypos -= 2.0 * spacing;
-    if (fringe.t201->epoch == 1950) sprintf (buf, "Position (B1950)");
-    else if (fringe.t201->epoch == 2000) sprintf (buf, "Position (J2000)");
-    else sprintf (buf, "Position (J??? )");
+    psleft (0.87, ypos, "fourfit exec/bld:"); ypos -= 3.0 * spacing;
+    if (fringe.t201->epoch == 1950) sprintf (buf, "RA & Dec (B1950)");
+    else if (fringe.t201->epoch == 2000) sprintf (buf, "RA & Dec (J2000)");
+    else sprintf (buf, "RA & Dec (J??? )");
     psleft (0.87, ypos, buf);
     setblack;
                                         /* Channel-by-channel text */
@@ -1333,6 +1368,8 @@ struct type_221 **t221)
               + 360 * fringe.t208->resid_mbd * 
                        (pass->pass_data[i].frequency 
                       - fringe.t205->ref_freq), 360.0)));
+	    // fmod returns -360 .. 360 depending on sign of the phase
+	    // pcoffset.*lsb is identical to pcoffset.*usb
             /*fprintf (stderr, "%lf %lf %lf %lf %lf %lf\n", 
                     (double)fringe.t207->ref_pcoffset[i].lsb, 
                     (double)fringe.t207->rem_pcoffset[i].lsb,
