@@ -416,13 +416,13 @@ int pol, fr, ap;
                                         // apply delay offset phase ramp
                                         // iff the offset is non-zero
     freq_no = fcode(pass->pass_data[fr].freq_code);
-    diff_delay = pass->control.delay_offs[freq_no].rem 
-               - pass->control.delay_offs[freq_no].ref;
+    diff_delay = pass->control.delay_offs[freq_no].ref 
+               - pass->control.delay_offs[freq_no].rem;
                                         // add in phase effects if multitone delays were extracted
     if (pass->control.nsamplers && param.pc_mode[0] == MULTITONE 
                                 && param.pc_mode[1] == MULTITONE)      
-        diff_delay += 1e9 * datum->rem_sdata.mt_delay[stnpol[1][pol]] 
-                          - datum->ref_sdata.mt_delay[stnpol[0][pol]];
+        diff_delay += 1e9 * (datum->ref_sdata.mt_delay[stnpol[0][pol]] 
+                           - datum->rem_sdata.mt_delay[stnpol[1][pol]]);
 
     if (diff_delay != 0.0)              // apply only non-zero delay effects
         {
