@@ -50,7 +50,7 @@ struct c_block *cb_ptr;
     cb_ptr -> ionosphere.rem  = NULLFLOAT;
     cb_ptr -> dc_block        = NULLINT;  
     cb_ptr -> nsamplers       = NULLINT;
-    cb_ptr -> sampler_codes[0]= NULL;
+    cb_ptr -> sampler_codes[0]= NULLCHAR;
     cb_ptr -> optimize_closure= NULLINT;  
 
     for (i=0; i<6; i++)
