@@ -451,7 +451,8 @@ int parser ()
                i = fcode(char_values[tval]);          /* get freq. array index */
                if (i<0 || i>MAX_CHAN_PP-1 || sideband<0) /* trap error conditions */
                    {
-                   msg ("Errant freq element: %s",2,char_values[tval]);
+                   msg ("Errant freq element: %c%c", 2, 
+                         char_values[tval], char_values[tval+1]);
                    return (-1);
                    }
                                         /* OK, load into appropriate c_blocks */
