@@ -47,7 +47,7 @@ struct data_corel
 
 struct freq_corel 
         {
-        char freq_code;         /* Fourfit frequency identifier (a-p) */
+        char freq_code;         /* Fourfit frequency identifier (a..zA..Z$%) */
         double frequency;       /* sky frequency (MHz) */
         char fgroup;
         char ch_usb_lcp[2][8];  /* VEX channel ids by station */
