@@ -139,7 +139,6 @@ void pcalibrate (struct type_pass *pass,
                       pc_avg[stn][i] = s_mult (pc_avg[stn][i], 1 / status.pcals_accum[stn]);
                   else 
                       pc_avg[stn][i] = c_zero ();
-
               if (param.pc_mode[stn] == MULTITONE)
                 {                   // in multitone mode, find peak of delay function
                                     // and correct phase to midband
@@ -187,7 +186,7 @@ void pcalibrate (struct type_pass *pass,
                         indpeak = i;
                         }
                                     // DC is in 0th element
-                indpeak = (indpeak < 128) ? indpeak : indpeak - 256;
+//              indpeak = (indpeak < 128) ? indpeak : indpeak - 256;
                 delay = indpeak / 256.0 / param.pcal_spacing[stn];       
 
                                     // interpolate to optimal value (NYI)
@@ -218,6 +217,7 @@ void pcalibrate (struct type_pass *pass,
                     kdatum = fdata->data + kap;
                     ksd = (stn == 0) ? &(kdatum->ref_sdata) : &(kdatum->rem_sdata);
                     ksd->mt_pcal[stnpol[stn][param.pol]] = pc_sub[stn];
+                    ksd->mt_delay[stnpol[stn][param.pol]] = delay;
                     }
                                     // maintain a running total
                 pc_adj[stn] = c_add (pc_sub[stn], pc_adj[stn]);
