@@ -28,6 +28,7 @@ struct type_pass *pass;
     double delay_offset, rate_offset, pcfreq_hz,
            pcphas[2], pcfreq[2];
     extern struct type_status status;
+    extern int do_accounting;
     static double conrad = 0.01745329252;
 
                                     /* copy over ref. frequency */
@@ -233,5 +234,6 @@ struct type_pass *pass;
     for (i=0; i<6; i++)
         param->ah_poly[i] = pass->control.adhoc_poly[i] * conrad;
 
+    if (do_accounting) account ("PreCorrect data");
     return (0);
     }
